==> klibido_0.2.3.orig.tar.gz: klibido-0.2.3.orig/src/fileviewer.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Alessandro Bonometti                            *
 *   bauno@inwind.it                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kparts/part.h>
#include <kmdichildview.h>
#include <kmimetype.h>
#include <qlayout.h>
#include <klibloader.h>
#include <kurl.h>

class FileViewer : public KMdiChildView
{
	private:
		KParts::ReadOnlyPart *m_view;
		KURL url;
		KLibFactory *factory;
		QHBoxLayout *top_layout;
		QString library;
		bool load();
		
		
	public:
		FileViewer(KURL _url, QWidget *parent);
		
		void reload(KURL _url);
		~FileViewer();
		virtual void closeEvent(QCloseEvent *e);
		
	

};

==> klibido_0.2.5.orig.tar.gz: klibido-0.2.5/src/fileviewer.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Alessandro Bonometti                            *
 *   bauno@inwind.it                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KLIBIDO_FILEVIEWER_H_
#define _KLIBIDO_FILEVIEWER_H_

#include <kparts/part.h>
#include <kmdichildview.h>
#include <kmimetype.h>
#include <qlayout.h>
#include <klibloader.h>
#include <kurl.h>

class FileViewer : public KMdiChildView
{
	private:
		KParts::ReadOnlyPart *m_view;
		KURL url;
		KLibFactory *factory;
		QHBoxLayout *top_layout;
		QString library;
		bool load();
		
		
	public:
		FileViewer(KURL _url, QWidget *parent);
		void closeAndDelete();
		void closeNoDelete();
		void reload(KURL _url);
		~FileViewer();
		virtual void closeEvent(QCloseEvent *e);
// 		virtual void close();
		
	

};

#endif //_KLIBIDO_FILEVIEWER_H_
